--AH:ScriptId=8898871a-e038-41cc-8f36-05a37b42b9a5;2973
--NuGet
INSERT INTO [Connectors]
(
	[Connector_Name],
	[Connector_Url],
	[FeedType_Name],
	[User_Name],
	[Password_Bytes],
	[Timeout_Period],
	[Filter_Csv]
)
SELECT DISTINCT NULLIF([Connector_Name], ''),
       [Connector_Url],
	   'NuGet',
	   [Connector_User_Name],
	   [Connector_Password],
	   [Timeout_Period],
	   NULLIF([Filter_Csv], '')
  FROM [NuGetConnectors]

INSERT INTO [FeedConnectors]
SELECT [Feed_Id],
       [Sequence_Number] = CAST(ROW_NUMBER() OVER (PARTITION BY [Feed_Id] ORDER BY [Connector_Id]) AS INT),
	   [Connector_Id] = (SELECT TOP 1 [Connector_Id]
	                       FROM [Connectors] C
						  WHERE C.[Connector_Url] = NC.[Connector_Url]
						    AND C.[FeedType_Name] = 'NuGet'
							AND COALESCE(C.[Connector_Name], '') = COALESCE(NC.[Connector_Name], '')
							AND COALESCE(C.[User_Name], '') = COALESCE(NC.[Connector_User_Name], '')
							AND COALESCE(C.[Password_Bytes], 0x) = COALESCE(NC.[Connector_Password], 0x)
							AND COALESCE(C.[Filter_Csv], '') = COALESCE(NC.[Filter_Csv], '')
							AND C.[Timeout_Period] = NC.[Timeout_Period])
  FROM [NuGetConnectors] NC
 

--Bower
INSERT INTO [Connectors]
(
	[Connector_Url],
	[FeedType_Name],
	[Timeout_Period],
	[Filter_Csv]
)
SELECT DISTINCT [Registry_Url],
       'Bower',
	   30,
	   NULLIF([Filter_Csv], '')
  FROM [BowerConnectors]

INSERT INTO [FeedConnectors]
SELECT [Feed_Id],
       [Sequence_Number],
	   [Connector_Id] = (SELECT TOP 1 [Connector_Id]
	                       FROM [Connectors] C
						  WHERE C.[Connector_Url] = BC.[Registry_Url]
						    AND C.[FeedType_Name] = 'Bower'
							AND COALESCE(BC.[Filter_Csv], '') = COALESCE(BC.[Filter_Csv], ''))
  FROM [BowerConnectors] BC


--Maven
INSERT INTO [Connectors]
(
	[Connector_Url],
	[FeedType_Name],
	[User_Name],
	[Password_Bytes],
	[Timeout_Period],
	[IndexUpdated_Date]
)
SELECT [Repository_Url],
       'Maven',
       CAST(CAST([UserName_Bytes] AS VARCHAR(200)) AS NVARCHAR(200)),
	   [Password_Bytes],
	   [Timeout_Period],
	   [ReceivedIndex_Date]
  FROM [MavenConnectors]

INSERT INTO [FeedConnectors]
SELECT [Feed_Id],
       [Sequence_Number] = CAST(ROW_NUMBER() OVER (PARTITION BY [Feed_Id] ORDER BY MC.[MavenConnector_Id]) AS INT),
	   [Connector_Id] = (SELECT TOP 1 [Connector_Id]
	                       FROM [Connectors] C
						  WHERE C.[Connector_Url] = MC.[Repository_Url]
						    AND C.[FeedType_Name] = 'Maven')
  FROM [MavenFeedConnectors] MFC
       INNER JOIN [MavenConnectors] MC
	           ON MC.[MavenConnector_Id] = MFC.[MavenConnector_Id]


--npm
INSERT INTO [Connectors]
(
	[Connector_Url],
	[FeedType_Name],
	[Timeout_Period],
	[IndexUpdated_Date]
)
SELECT [Registry_Url],
       'npm',
	   30,
	   [Updated_Date]
  FROM [NpmConnectors]

INSERT INTO [FeedConnectors]
SELECT [Feed_Id],
       [Sequence_Number] = CAST(ROW_NUMBER() OVER (PARTITION BY [Feed_Id] ORDER BY NC.[NpmConnector_Id]) AS INT),
	   [Connector_Id] = (SELECT TOP 1 [Connector_Id]
	                       FROM [Connectors] C
						  WHERE C.[Connector_Url] = NC.[Registry_Url]
						    AND C.[FeedType_Name] = 'npm')
  FROM [NpmFeedConnectors] NFC
       INNER JOIN [NpmConnectors] NC
	           ON NC.[NpmConnector_Id] = NFC.[NpmConnector_Id]

			   
GO

ALTER TABLE [ScheduledTasks]
	ADD [Connector_Id] INT NULL

GO

UPDATE ST
   SET ST.[Connector_Id] = (SELECT TOP 1 C.[Connector_Id]
                              FROM [Connectors] C
							 WHERE C.[Connector_Url] = NC.[Registry_Url])
  FROM [ScheduledTasks] ST
       INNER JOIN [NpmConnectors] NC
	           ON NC.[NpmConnector_Id] = ST.[NpmConnector_Id]

UPDATE ST
   SET ST.[Connector_Id] = (SELECT TOP 1 C.[Connector_Id]
                              FROM [Connectors] C
							 WHERE C.[Connector_Url] = MC.[Repository_Url])
  FROM [ScheduledTasks] ST
       INNER JOIN [MavenConnectors] MC
	           ON MC.[MavenConnector_Id] = ST.[MavenConnector_Id]

GO

ALTER TABLE [ScheduledTasks]
	ADD CONSTRAINT [FK__ScheduledTasks__Connectors]
		FOREIGN KEY ([Connector_Id])
		REFERENCES [Connectors] ([Connector_Id])
		ON DELETE CASCADE

ALTER TABLE [ScheduledTasks]
	DROP CONSTRAINT [FK__ScheduledTasks__MavenConnectors]

ALTER TABLE [ScheduledTasks]
	DROP CONSTRAINT [FK__ScheduledTasks__NpmConnectors]

ALTER TABLE [ScheduledTasks]
	DROP CONSTRAINT [UQ__ScheduledTasks]

ALTER TABLE [ScheduledTasks]
	DROP CONSTRAINT [CK__ScheduledTasks__Context]

GO

ALTER TABLE [ScheduledTasks]
	ADD CONSTRAINT [CK__ScheduledTasks__Context]
		CHECK ([Feed_Id] IS NULL OR [Connector_Id] IS NULL)

ALTER TABLE [ScheduledTasks]
	DROP COLUMN [NpmConnector_Id]

ALTER TABLE [ScheduledTasks]
	DROP COLUMN [MavenConnector_Id]



DROP TABLE [NpmConnectorPackages]
GO

CREATE TABLE [NpmConnectorPackages]
(
	[Connector_Id] INT NOT NULL,
	[Package_Name] NVARCHAR(200) NOT NULL,
	[Package_Version] VARCHAR(200) NOT NULL,
	[Modified_Date] DATETIME NOT NULL,
	[PackageJson_Bytes] VARBINARY(MAX) NOT NULL,

	CONSTRAINT [PK__NpmConnectorPackages]
		PRIMARY KEY ([Connector_Id], [Package_Name]),

	CONSTRAINT [FK__NpmConnectorPackages]
		FOREIGN KEY ([Connector_Id])
		REFERENCES [Connectors] ([Connector_Id])
		ON DELETE CASCADE,

	CONSTRAINT [CK__NpmConnectorPackages__Package_Name]
		CHECK ([Package_Name] <> '' AND NOT [Package_Name] LIKE '-%'),

	CONSTRAINT [CK__NpmConnectorPackages__Package_Version]
		CHECK ([Package_Version] <> '')
)
GO
