EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackages_DeletePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a package from a feed.'
GO

IF OBJECT_ID('[NuGetPackages_DeletePackage]') IS NOT NULL DROP PROCEDURE [NuGetPackages_DeletePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NuGetPackages_DeletePackage]
(
	@Feed_Id INT,
	@Package_Id NVARCHAR(255),
	@Version_Text NVARCHAR(50)
)
AS
BEGIN

	SET NOCOUNT ON

	BEGIN TRY
		BEGIN TRANSACTION

		IF EXISTS(SELECT * FROM [NuGetPackages] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Package_Id] = @Package_Id AND [Version_Text] = @Version_Text)
		BEGIN

			DELETE [NuGetPackageSymbols]
			 WHERE [Feed_Id] = @Feed_Id
			   AND [Package_Id] = @Package_Id
			   AND [Package_Version_Text] = @Version_Text

			DELETE [NuGetPackages]
			 WHERE [Feed_Id] = @Feed_Id
			   AND [Package_Id] = @Package_Id
			   AND [Version_Text] = @Version_Text

			EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Package_Name', @Package_Id, 'Package_Version', @Version_Text

		END

		COMMIT
	END TRY BEGIN CATCH
		IF XACT_STATE()<>0 ROLLBACK
		EXEC [HandleError]
	END CATCH

END
GO

GRANT EXECUTE ON [NuGetPackages_DeletePackage] TO [ProGetUser_Role]
GO
